@@ -97,9 +97,11 @@ def project_polygon(original: Polygon, total_load: Optional[float] = None, xy: b
 
     if xy:
         x, y = singularities_to_polygon(sings, xy=xy)
-        if len(y) == len(x) + 1: # HACK to return consistent xy trapezoid coords
-            return x[1:-2], y[1:-1]
-        return x[1:-1], y[1:-1]
+        # if len(y) == len(x) + 1: # HACK to return consistent xy trapezoid coords
+        #     return x[1:-2], y[1:-1]
+        # elif len(x) == len(y) + 1:
+        #     return x[1:-1], y[1:-2]
+        return x, y
     result = singularities_to_polygon(sings, xy=xy)
     return result
 
@@ -123,13 +125,11 @@ def singularities_to_polygon(los: list[Singularity], xy: bool = False) -> Polygo
     """
     sorted_sings = sorted(los, key=lambda x: x.x1)
     x_acc = []
-    prev_x = 0
+    prev_x = None
     for idx, sing in enumerate(sorted_sings):
         n = sing.precision
         eps = 10**(-2*n)
-        # if idx == 0:
-        #     x_acc.append(0.)
-        if prev_x != sing.x0:
+        if prev_x != sing.x0 and prev_x is not None:
             x_acc.append(prev_x + eps)
         x_acc.append(sing.x0)
         x_acc.append(sing.x0 + eps)
